.. include:: _common.rst

Installation
============

|name| is distributed as a Python package available at BBP devpi server:

.. code-block:: console

    $ pip install -i https://bbpteam.epfl.ch/repository/devpi/simple/ neuroc

Only Python 3.6+ is supported at the moment.

Prior to running *pip install*, we recommend updating *pip* in your virtual environment unless you have a compelling reason not to do it:

.. code:: console

    $ pip install --upgrade pip setuptools
